@@ -28,3 +28,9 @@ REFERENCE_VALUE_PREFIX = b'\x01'
 
 OLDEST_FIRST = False
 NEWEST_FIRST = True
+
+COLUMN_NAME_MODE_FULL = 255
+COLUMN_NAME_MODE_DATABASE = 3
+COLUMN_NAME_MODE_TABLE = 2
+COLUMN_NAME_MODE_FIELD = 1
+COLUMN_NAME_MODE_NONE = 0
